@@ -5,12 +5,13 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\URL;
+use PMA\libraries\Response;
 
 /**
  *
  */
 require_once 'libraries/common.inc.php';
-require_once 'libraries/mysql_charsets.inc.php';
 require_once 'libraries/sql.lib.php';
 
 if (isset($_REQUEST['submit_mult'])) {
@@ -37,6 +38,7 @@ if (! isset($submit_mult)) {
 switch($submit_mult) {
 case 'row_delete':
 case 'row_edit':
+case 'row_copy':
 case 'row_export':
     // leave as is
     break;
@@ -49,23 +51,32 @@ case 'delete':
     $submit_mult = 'row_delete';
     break;
 
-default:
+case 'copy':
+    $submit_mult = 'row_copy';
+    break;
+
 case 'edit':
+default:
     $submit_mult = 'row_edit';
     break;
 }
 
 if (!empty($submit_mult)) {
 
-    if (! isset($_REQUEST['rows_to_delete'])
-        || ! is_array($_REQUEST['rows_to_delete'])
+    if (isset($_REQUEST['goto'])
+        && (! isset($_REQUEST['rows_to_delete'])
+        || ! is_array($_REQUEST['rows_to_delete']))
     ) {
-        $response = PMA_Response::getInstance();
-        $response->isSuccess(false);
+        $response = Response::getInstance();
+        $response->setRequestStatus(false);
         $response->addJSON('message', __('No row selected.'));
     }
 
     switch($submit_mult) {
+    /** @noinspection PhpMissingBreakStatementInspection */
+    case 'row_copy':
+        $_REQUEST['default_action'] = 'insert';
+        // no break to allow for fallthough
     case 'row_edit':
         // As we got the rows to be edited from the
         // 'rows_to_delete' checkbox, we use the index of it as the
@@ -76,7 +87,7 @@ if (!empty($submit_mult)) {
             && is_array($_REQUEST['rows_to_delete'])
         ) {
             foreach ($_REQUEST['rows_to_delete'] as $i => $i_where_clause) {
-                $where_clause[] = urldecode($i_where_clause);
+                $where_clause[] = $i_where_clause;
             }
         }
         $active_page = 'tbl_change.php';
@@ -96,7 +107,7 @@ if (!empty($submit_mult)) {
             && is_array($_REQUEST['rows_to_delete'])
         ) {
             foreach ($_REQUEST['rows_to_delete'] as $i => $i_where_clause) {
-                $where_clause[] = urldecode($i_where_clause);
+                $where_clause[] = $i_where_clause;
             }
         }
         $active_page = 'tbl_export.php';
@@ -107,7 +118,7 @@ if (!empty($submit_mult)) {
     default:
         $action = 'tbl_row_action.php';
         $err_url = 'tbl_row_action.php'
-            . PMA_URL_getCommon($GLOBALS['url_params']);
+            . URL::getCommon($GLOBALS['url_params']);
         if (! isset($_REQUEST['mult_btn'])) {
             $original_sql_query = $sql_query;
             if (! empty($url_query)) {
@@ -117,7 +128,7 @@ if (!empty($submit_mult)) {
         include 'libraries/mult_submits.inc.php';
         $_url_params = $GLOBALS['url_params'];
         $_url_params['goto'] = 'tbl_sql.php';
-        $url_query = PMA_URL_getCommon($_url_params);
+        $url_query = URL::getCommon($_url_params);
 
 
         /**
@@ -140,16 +151,25 @@ if (!empty($submit_mult)) {
         }
 
         $active_page = 'sql.php';
-        /**
-         * Parse and analyze the query
-         */
-        include_once 'libraries/parse_analyze.inc.php';
-
         PMA_executeQueryAndSendQueryResponse(
-            $analyzed_sql_results, false, $db, $table, null, null, null, false, null,
-            null, null, $goto, $pmaThemeImage, null, null, null, $sql_query,
-            null, null
+            null, // analyzed_sql_results
+            false, // is_gotofile
+            $db, // db
+            $table, // table
+            null, // find_real_end
+            null, // sql_query_for_bookmark
+            null, // extra_data
+            null, // message_to_show
+            null, // message
+            null, // sql_data
+            $goto, // goto
+            $pmaThemeImage, // pmaThemeImage
+            null, // disp_query
+            null, // disp_message
+            null, // query_type
+            $sql_query, // sql_query
+            null, // selectedTables
+            null // complete_query
         );
     }
 }
-?>
